# PyCon India

![PyPI](https://img.shields.io/pypi/v/pyconindia?style=for-the-badge) ![PyPI - Status](https://img.shields.io/pypi/status/pyconindia?style=for-the-badge) ![PyPI - Downloads](https://img.shields.io/pypi/dw/pyconindia?style=for-the-badge) ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyconindia?style=for-the-badge)

PyCon India is the largest gathering of Pythonistas in India for the Python programming language. The 13th edition of PyCon India will be taking place online from 17th September to 20th September 2021. With this unique scenario at hand, we plan to make this year's conference bigger, better, and more accessible to Pythonistas all across the world who can watch, participate and share their views right from the comfort of their homes.

Install : `pip install pyconindia`

```python
>>> import pyconindia
>>> pyconindia.year
2021
>>> pyconindia.location
'Anywhere on Earth'
>>> pyconindia.cfp
'Submit your proposal: https://in.pycon.org/cfp/2021/proposals/'
```

